//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/InstrumentsCatalog.cpp
//! @brief     Implements class InstrumentsCatalog.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Device/InstrumentsCatalog.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Device/InstrumentItems.h"

InstrumentItem* InstrumentsCatalog::create(Type type)
{
    switch (type) {
    case Type::GISAS:
        return new GISASInstrumentItem();
    case Type::Offspec:
        return new OffspecInstrumentItem();
    case Type::Specular:
        return new SpecularInstrumentItem();
    case Type::Depthprobe:
        return new DepthprobeInstrumentItem();
    }
    ASSERT_NEVER;
}

QVector<InstrumentsCatalog::Type> InstrumentsCatalog::types()
{
    return {Type::GISAS, Type::Offspec, Type::Specular, Type::Depthprobe};
}

UiInfo InstrumentsCatalog::uiInfo(Type type)
{
    switch (type) {
    case Type::GISAS:
        return {"GISAS", "", ""};
    case Type::Offspec:
        return {"Off specular", "", ""};
    case Type::Specular:
        return {"Specular", "", ""};
    case Type::Depthprobe:
        return {"Depth probe", "", ""};
    }
    ASSERT_NEVER;
}

InstrumentsCatalog::Type InstrumentsCatalog::type(const InstrumentItem* item)
{
    if (dynamic_cast<const GISASInstrumentItem*>(item))
        return Type::GISAS;
    if (dynamic_cast<const OffspecInstrumentItem*>(item))
        return Type::Offspec;
    if (dynamic_cast<const SpecularInstrumentItem*>(item))
        return Type::Specular;
    if (dynamic_cast<const DepthprobeInstrumentItem*>(item))
        return Type::Depthprobe;

    ASSERT_NEVER;
}
