//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Files/DatafilesQModel.cpp
//! @brief     Implements class DatafilesQModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Files/DatafilesQModel.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/Model/Files/DatafilesSet.h"

DatafilesQModel::DatafilesQModel(QObject* parent, DatafilesSet* model)
    : QAbstractListModel(parent)
    , m_model(model)
{
}

void DatafilesQModel::injectDatafileItem(DatafileItem* item)
{
    const int row = m_model->size();
    beginInsertRows({}, row, row);
    m_model->appendDatafileItem(item);
    endInsertRows();
}

void DatafilesQModel::removeDatafileItemAt(int row)
{
    ASSERT(0 <= row && row < (int)m_model->size());
    beginRemoveRows({}, row, row);
    m_model->deleteDatafileItemAt(row);
    endRemoveRows();
}

const DatafileItem* DatafilesQModel::topMostItem() const
{
    if (m_model->size() > 0)
        return m_model->dfileItemAt(0);
    return nullptr;
}

int DatafilesQModel::rowCount(const QModelIndex& /*parent*/) const
{
    return m_model->size();
}

QVariant DatafilesQModel::data(const QModelIndex& index, int role) const
{
    if (!index.isValid() || index.row() >= (int)m_model->size() || index.row() < 0)
        return {};

    const auto* item = itemForIndex(index);
    ASSERT(item);

    if (role == Qt::DisplayRole)
        return item->realItemName();

    if (role == Qt::ToolTipRole)
        return {};

    return {};
}

DatafileItem* DatafilesQModel::itemForIndex(const QModelIndex& index) const
{
    if (!index.isValid() || index.row() >= (int)m_model->size() || index.row() < 0)
        return nullptr;
    return m_model->dfileItemAt(index.row());
}

QModelIndex DatafilesQModel::indexForItem(const DatafileItem* item) const
{
    for (size_t i = 0; i < m_model->size(); ++i)
        if (m_model->dfileItemAt(i) == item)
            return createIndex(i, 0, item);
    return {};
}
