//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Job/DataSource.h
//! @brief     Defines class DataSource.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_JOB_DATASOURCE_H
#define BORNAGAIN_GUI_MODEL_JOB_DATASOURCE_H

#include <QObject>

class Data1DItem;
class Data2DItem;
class DataItem;
class JobItem;

//! The DataSource class is a base for widgets, working data, stored in JobItem or
//! DatafileItem. DataSource provides an access to SpecularDataItems and Data2DItems
//! separately and as a list of items that is required for simultaneous, synchronous work while
//! plotting and changing their properties.

class DataSource {
public:
    explicit DataSource(QObject* item);

    JobItem* jobxItem() const;

    //... Access to concrete items:

    Data1DItem* realData1DItem() const;
    Data2DItem* realData2DItem() const;

    Data1DItem* simuData1DItem() const;
    Data2DItem* simuData2DItem() const;

    Data1DItem* diffData1DItem() const;
    Data2DItem* diffData2DItem() const;

    //... Access to lists of items:

    QVector<Data1DItem*> mainData1DItems() const;
    QVector<Data2DItem*> mainData2DItems() const;

    QVector<Data1DItem*> allData1DItems() const;
    QVector<Data2DItem*> allData2DItems() const;

    Data1DItem* currentData1DItem() const;
    Data2DItem* currentData2DItem() const;

private:
    DataItem* realDataItem() const;

    QObject* m_item;
};

#endif // BORNAGAIN_GUI_MODEL_JOB_DATASOURCE_H
