//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/MasksQModel.h
//! @brief     Defines class MasksQModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H
#define BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H

#include <QAbstractListModel>
#include <QItemSelectionModel>
#include <QModelIndex>
#include <QVariant>

class MaskItem;
class MasksSet;
class OverlayItem;
class ProjectionsSet;

//! Provides interfaces to a MasksSet, allowing its contents to be displayed and modified
//! using the Qt mechanisms.

class MasksQModel : public QAbstractListModel {
    Q_OBJECT
public:
    MasksQModel(MasksSet* set);
    ~MasksQModel();

    //... Override functions from QAbstractListModel

    QVariant data(const QModelIndex& index, int role) const override;
    int rowCount(const QModelIndex& parent) const override;

    //... Other functions

    void insertMask(int row, MaskItem* item);
    void removeMask(MaskItem* item);
    void removeSelected();
    void clear(); //!< Removes all masks

    void moveMask(int from_row, int to_row);
    void removeMaskAt(int row);
    void moveUp();
    void moveDown();

    void toggleMaskValue(); //!< Toggles mask value for all selected items.

    QModelIndex indexOfItem(const OverlayItem* item) const; // TODO: change this to MaskItem*
    MaskItem* itemForIndex(const QModelIndex& index) const;

    QItemSelectionModel* maskSelectionModel() { return m_selection_model.get(); }

    MasksSet* masksSet() { return m_masks; }
    const MasksSet* masksSet() const { return m_masks; }
    ProjectionsSet* projnItem();
    const ProjectionsSet* projnItem() const;

private:
    MasksSet* m_masks;
    std::unique_ptr<QItemSelectionModel> m_selection_model;
};

#endif // BORNAGAIN_GUI_MODEL_MASK_MASKSQMODEL_H
