//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/MasksSet.h
//! @brief     Defines class MasksSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H
#define BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H

#include "Base/Types/OwningVector.h"
#include "GUI/Model/Descriptor/PolyVector.h"
#include "GUI/Model/Mask/MasksCatalog.h"
#include <QModelIndex>
#include <QXmlStreamWriter>

class MaskItem;
class MessageService;
class RegionOfInterestItem;

//! Container holding various masks as children

class MasksSet {
public:
    MasksSet();
    virtual ~MasksSet();

    QVector<MaskItem*> maskItemsQ() const;

    //! Insert mask at given row.
    void insertMask(int row, MaskItem* maskItem);

    void addMaskItem(MaskItem* maskItem);

    //! Move mask to a given row
    void moveMask(int from_row, int to_row);

    void removeMaskAt(int row);

    //! Can be nullptr.
    RegionOfInterestItem* regionOfInterestItem() const;

    //! Remove all masks
    void clear();

    //! Return true if the container has no MaskItems
    bool isEmpty() const;

    //! Return the number of MaskItems
    int size() const;

    //! Return the MaskItem at a given index
    int indexOfItem(const MaskItem* maskItem) const;

    //! Return the index corresponding to a given MaskItem
    MaskItem* at(const int idx);

    //! Serialize/deserialize
    void writeTo(QXmlStreamWriter* w) const;
    void readFrom(QXmlStreamReader* r, MessageService* messageService = nullptr);

    //! Update numbers in mask names
    void updateMaskNames();

    const QModelIndex rootIndex;

protected:
    PolyVector<MasksCatalog> m_mask_items;
};

#endif // BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H
