//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/ProjectionsSet.h
//! @brief     Defines items related to projections over color map.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MASK_PROJECTIONSSET_H
#define BORNAGAIN_GUI_MODEL_MASK_PROJECTIONSSET_H

#include "GUI/Model/Mask/MasksSet.h"
#include "GUI/Support/Data/ID.h"

class LineItem;

//! A container to hold ProjectionsSet, intended to store projections of color map on X, Y
//! axes.

class ProjectionsSet : public MasksSet {
public:
    ProjectionsSet();

    QVector<const LineItem*> projectionsOfType(Qt::Orientation projectionType) const;

private:
    template <typename LineType> QVector<const LineItem*> projections() const
    {
        QVector<const LineItem*> result;
        for (const auto& proj : m_mask_items)
            if (const auto* line_item = dynamic_cast<const LineType*>(proj.certainItem()))
                result.push_back(line_item);
        return result;
    }
};


#endif // BORNAGAIN_GUI_MODEL_MASK_PROJECTIONSSET_H
