//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/SamplesSet.h
//! @brief     Defines class SamplesSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLESSET_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLESSET_H

#include "Base/Types/OwningVector.h"
#include <QVector>
#include <QXmlStreamReader>

class SampleItem;

//! Main model to hold sample items.

class SamplesSet {
public:
    ~SamplesSet();
    QVector<SampleItem*> sampleItems() const;

    SampleItem* addSampleItem();
    void addSampleItem(SampleItem* sample);

    void removeSample(SampleItem* sample);

    QStringList sampleNames() const;

    void writeTo(QXmlStreamWriter* w) const;
    void readFrom(QXmlStreamReader* r);

    int currentIndex() const { return m_current_index; }
    void setCurrentIndex(int newIndex) { m_current_index = newIndex; }

private:
    OwningVector<SampleItem> m_samples;
    int m_current_index = 0;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_SAMPLESSET_H
