//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/DatafilesSelector.h
//! @brief     Defines class DatafilesSelector.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_DATA_DATAFILESSELECTOR_H
#define BORNAGAIN_GUI_VIEW_DATA_DATAFILESSELECTOR_H

#include <QModelIndex>
#include <QTreeView>
#include <QWidget>

class DatafileEditor;
class DatafileItem;
class DatafilesQModel;
class StackedDataFrames;

//! For viewing and selecting loaded datafiles.
//!
//! Shown as left panel in DataView.
//!
//! Contains a listing of loaded datafiles (m_qview & m_qmodel)
//! and an editor for acting on the currently selected datafile (DatafileEditor).

class DatafilesSelector : public QWidget {
    Q_OBJECT
public:
    DatafilesSelector(StackedDataFrames*);

    QSize sizeHint() const override;
    QSize minimumSizeHint() const override;

    DatafileItem* currentDatafileItem();

private:
    void setCurrentDatafileItem(const DatafileItem* item);
    void restoreSelection();
    void onSelectionChanged();
    void renameCurrentItem();
    void removeCurrentItem();
    void updateActionEnabling();
    void updateActionEnabling(const DatafileItem* item) const;
    void updateFunctionalities();
    void onContextMenuRequest(const QPoint& point);
    void importData1D();
    void importData2D();
    QModelIndex currentDatafileIndex() const;

    QVector<QAction*> getOverlayActions(const QModelIndex& index, bool asHover);

    QAction* m_import1dData_action;
    QAction* m_import2dData_action;
    QAction* m_rename_data_action;
    QAction* m_remove_data_action;

    QTreeView* m_qview;
    DatafilesQModel* m_qmodel;
    DatafileEditor* m_editor;
    StackedDataFrames* m_data_frames;
};

#endif // BORNAGAIN_GUI_VIEW_DATA_DATAFILESSELECTOR_H
