//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Frame/StackedFrames.h
//! @brief     Defines class StackedFrames and children.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_FRAME_STACKEDFRAMES_H
#define BORNAGAIN_GUI_VIEW_FRAME_STACKEDFRAMES_H

#include <QMap>
#include <QStackedWidget>

class StackedFrames : public QStackedWidget {
public:
    StackedFrames();

    //! Shows the widget for given item (and hides previous one).
    //! If no widget yet exists, it will be created.
    void setStackedItem(QObject* item);

private:
    virtual QWidget* newFrame(QObject*) const = 0;

    QMap<QObject*, QWidget*> m_item_to_widget;
};

class StackedDataFrames : public StackedFrames {
private:
    QWidget* newFrame(QObject*) const override;
};

class StackedJobFrames : public StackedFrames {
private:
    QWidget* newFrame(QObject*) const override;
};

#endif // BORNAGAIN_GUI_VIEW_FRAME_STACKEDFRAMES_H
