//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/List/SamplesQModel.h
//! @brief     Defines class SamplesQModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LIST_SAMPLESQMODEL_H
#define BORNAGAIN_GUI_VIEW_LIST_SAMPLESQMODEL_H

#include <QAbstractItemModel>

class SampleItem;

//! Data model for SamplesQListView.

class SamplesQModel : public QAbstractListModel {
    Q_OBJECT
public:
    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    SampleItem* itemForIndex(const QModelIndex& index) const;
    QModelIndex indexForItem(SampleItem* item) const;

    //! Remove the given sample. nullptr is allowed.
    void removeSample(SampleItem* item);

    //! Copy the given sample.
    QModelIndex copySample(SampleItem* item);

    //! Create a new sample (sample) and return the index of it.
    QModelIndex createSample();

    //! Create sample from list of built-in examples.
    //!
    //! Returns invalid index if anything went wrong.
    QModelIndex createSampleFromExamples(const QString& className, const QString& title,
                                         const QString& description);

#ifdef BORNAGAIN_PYTHON
    //! Create sample from an imported python code.
    //!
    //! Returns invalid index if anything went wrong.
    QModelIndex createSampleFromPython();
#endif
};

#endif // BORNAGAIN_GUI_VIEW_LIST_SAMPLESQMODEL_H
