//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Main/ActionManager.h
//! @brief     Defines class ActionManager.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_MAIN_ACTIONMANAGER_H
#define BORNAGAIN_GUI_VIEW_MAIN_ACTIONMANAGER_H

#include <QAction>
#include <QMenu>
#include <QMenuBar>
#include <QObject>
#include <QShortcut>

class MainWindow;

//! Class to handle MainWindow's menu and corresponding actions

class ActionManager : public QObject {
    Q_OBJECT
public:
    ActionManager(MainWindow* parent);

private slots:
    void onAboutToShowFileMenu();
    void onAboutToShowSettingsMenu();
    void onAboutToShowViewMenu();
    void onAboutApplication();
    void onCurrentViewChanged();

private:
    void updateActionEnabling();

private:
    MainWindow* m_main_window;

    QAction* m_new_action;
    QAction* m_open_action;
    QAction* m_save_action;
    QAction* m_save_as_action;
    QAction* m_close_project_action;
    QAction* m_exit_action;
    QAction* m_webdoc_action;
    QAction* m_about_action;

    QMenuBar* m_menu_bar;
    QMenu* m_file_menu;
    QMenu* m_settings_menu;
    QMenu* m_view_menu;
    QMenu* m_recent_projects_menu;
    QMenu* m_help_menu;

    QShortcut* m_simulate_shortcut;

    void createActions();
    void createMenus();
    void createGlobalShortcuts();
};

#endif // BORNAGAIN_GUI_VIEW_MAIN_ACTIONMANAGER_H
