//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Main/MainWindow.h
//! @brief     Defines class MainWindow.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_MAIN_MAINWINDOW_H
#define BORNAGAIN_GUI_VIEW_MAIN_MAINWINDOW_H

#include "GUI/Support/Data/ID.h"
#include <QButtonGroup>
#include <QMainWindow>
#include <QProgressBar>
#include <QStackedLayout>
#include <QStatusBar>
#include <QToolButton>
#include <QVBoxLayout>

class ActionManager;
class DataView;
class InstrumentView;
class JobView;
class ProjectManager;
class ProjectsView;
class SampleView;
class SimulationView;

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    explicit MainWindow();
    ~MainWindow() override;

    QProgressBar* progressBar() { return m_progress_bar; }

    ProjectManager* projectManager() { return m_project_manager; }

    QWidget* currentView() const;
    void setCurrentView(int viewId);

    void updateTitle();
    void loadProject(QString projectPath);

public slots:
    void openRecentProject();
    void onRunSimulationShortcut();

signals:
    void currentViewChanged(GUI::ID::ViewId newView);

protected:
    void closeEvent(QCloseEvent* event) override;

private:
    void initApplication();
    void initProgressBar();
    void initButtons();
    void initViews();

    void readSettings();
    void writeSettings();
    void addButton(GUI::ID::ViewId id, const QIcon& icon, const QString& title,
                   const QString& tooltip);
    void resetView(GUI::ID::ViewId id, QWidget* view);
    QToolButton* createViewSelectionButton() const;

    //! Recalculate the size of the view selection buttons to show complete button text
    void updateViewSelectionButtonsGeometry() const;
    void onDocumentOpenedOrClosed(bool open);
    void onDocumentModified();
    void onAboutToCloseDocument();

    void raiseView(int viewId);

    QProgressBar* m_progress_bar;
    QButtonGroup* m_view_selection_buttons;
    QStackedLayout* m_views_stack;
    QVBoxLayout* m_view_selection_buttons_layout;

    ProjectManager* m_project_manager;
    ActionManager* m_action_manager;

    ProjectsView* m_projects_view;
    InstrumentView* m_instrument_view;
    SampleView* m_sample_view;
    DataView* m_data_view;
    SimulationView* m_simulation_view;
    JobView* m_job_view;
};

#endif // BORNAGAIN_GUI_VIEW_MAIN_MAINWINDOW_H
