//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Sample/SampleEditor.cpp
//! @brief     Implements class SampleEditor.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Sample/SampleEditor.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/Model/Sample/LayerItem.h"
#include "GUI/Model/Sample/SampleItem.h"
#include "GUI/View/Layout/ApplicationSettings.h"
#include "GUI/View/Sample/LayerEditorUtil.h"
#include "GUI/View/Sample/SampleEditorController.h"
#include "GUI/View/Sample/SampleForm.h"
#include "GUI/View/Widget/StyledToolbar.h"
#include <QActionGroup>
#include <QBoxLayout>
#include <QPushButton>

SampleEditor::SampleEditor()
    : m_current_sample_widget(nullptr)
{
    QScrollArea::setWidgetResizable(true);
    QScrollArea::setWidget(new QWidget());
}

SampleEditor::~SampleEditor()
{
    qDeleteAll(m_edit_controllers.values());
}

void SampleEditor::setCurrentSample(SampleItem* sampleItem)
{
    if (m_current_sample != nullptr)
        m_edit_controllers[m_current_sample]->setSampleForm(nullptr);

    m_current_sample_widget = nullptr;
    delete QScrollArea::takeWidget();

    m_current_sample = sampleItem;
    if (m_current_sample == nullptr) {
        QScrollArea::setWidget(new QWidget());
        return;
    }

    if (!m_edit_controllers.contains(m_current_sample))
        m_edit_controllers.insert(m_current_sample, new SampleEditorController(m_current_sample));
    auto* ec = m_edit_controllers[m_current_sample];
    connect(ec, &SampleEditorController::requestViewInRealspace, this,
            &SampleEditor::requestViewInRealspace);
    connect(ec, &SampleEditorController::aboutToRemoveItem, this, &SampleEditor::aboutToRemoveItem);
    connect(ec, &SampleEditorController::modified, this, &SampleEditor::modified);

    createLayerColors();

    m_current_sample_widget = new SampleForm(m_current_sample, ec);
    ec->setSampleForm(m_current_sample_widget);
    m_current_sample_widget->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
    QScrollArea::setWidget(m_current_sample_widget);
}

void SampleEditor::createLayerColors() // #baLayerEditor move to better place
{
    if (!m_current_sample)
        return;

    int col = 0;
    for (auto* l : m_current_sample->layerItems()) {
        if (l->color().isValid())
            continue;

        l->setColor(GUI::Util::Layer::predefinedLayerColors()[col]);
        col++;
        if (col == GUI::Util::Layer::predefinedLayerColors().size())
            col = 0;
    }
}
