//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Views/DataView.cpp
//! @brief     Implements class DataView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Views/DataView.h"
#include "GUI/Model/Data/DataItem.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/View/Data/DatafilesSelector.h"
#include "GUI/View/Frame/StackedFrames.h"
#include <QSplitter>
#include <QVBoxLayout>

DataView::DataView()
{
    auto* mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    mainLayout->setSpacing(0);

    auto* splitter = new QSplitter;
    mainLayout->addWidget(splitter);

    auto* stacked_frames = new StackedDataFrames;
    auto* selector = new DatafilesSelector(stacked_frames);

    splitter->addWidget(selector);
    splitter->addWidget(stacked_frames);

    splitter->setCollapsible(0, false);
    splitter->setCollapsible(1, false);

    if (DatafileItem* dfi = selector->currentDatafileItem())
        stacked_frames->setStackedItem(dfi->dataItem());
}
