//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Views/InstrumentView.h
//! @brief     Defines class InstrumentView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_VIEWS_INSTRUMENTVIEW_H
#define BORNAGAIN_GUI_VIEW_VIEWS_INSTRUMENTVIEW_H

#include <QCheckBox>
#include <QScrollArea>
#include <QWidget>

class InstrumentItem;
class InstrumentsQListView;

class InstrumentView : public QWidget {
    Q_OBJECT
public:
    InstrumentView();

private:
    void showEvent(QShowEvent*) override;
    void hideEvent(QHideEvent*) override;

    void subscribeOnExternalUpdates();
    void createWidgetsForCurrentInstrument();
    void onInstrumentNameEdited(const QString& newName);
    void onInstrumentdescriptionEdited(const QString& t);
    void onInstrumentChangedByEditor();
    void onInstrumentChangedFromExternal(const InstrumentItem* instrument);
    void onSingleInstrumentModeChanged(bool newState);

    InstrumentsQListView* m_listing;
    QScrollArea* m_scroll_area;
    QCheckBox* gisasCheck;
    QCheckBox* offspecCheck;
    QCheckBox* specularCheck;
    QCheckBox* depthProbeCheck;
};

#endif // BORNAGAIN_GUI_VIEW_VIEWS_INSTRUMENTVIEW_H
