//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Views/SampleView.h
//! @brief     Defines class SampleView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_VIEWS_SAMPLEVIEW_H
#define BORNAGAIN_GUI_VIEW_VIEWS_SAMPLEVIEW_H

#include <QShowEvent>
#include <QWidget>

class Item3D;
class RealspacePanel;
class SamplesQListView;

class SampleView : public QWidget {
    Q_OBJECT
public:
    SampleView();
    ~SampleView();

private:
    void showEvent(QShowEvent*) override;

    //! Show the item in the real space view
    //!
    //! If the real space view is not visible at the moment, it will be shown.
    void onRequestViewInRealspace(Item3D* item);

    void onAboutToRemoveItem(Item3D* item);

    void applySplitterPos();
    void saveSplitterPos();

    RealspacePanel* m_realspace_panel;
    SamplesQListView* m_listing;
};

#endif // BORNAGAIN_GUI_VIEW_VIEWS_SAMPLEVIEW_H
