//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Widget/ItemViewOverlayButtons.h
//! @brief     Defines class ItemViewOverlayButtons.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_WIDGET_ITEMVIEWOVERLAYBUTTONS_H
#define BORNAGAIN_GUI_VIEW_WIDGET_ITEMVIEWOVERLAYBUTTONS_H

#include <QAbstractItemView>
#include <QAction>
#include <QObject>
#include <functional>

//! Supports action buttons in the single rows of a list view.
//! Buttons may be permanent or only show up when hovered over.
//!
//! In feb24, this code was restricted from self-made views to list views.

class ItemViewOverlayButtons : public QObject {
    Q_OBJECT
public:
    using FnGetActions = std::function<QVector<QAction*>(const QModelIndex&, bool)>;

    static void install(QAbstractItemView* view, FnGetActions fnGetActions);

private:
    bool eventFilter(QObject* obj, QEvent* event) override;

    ItemViewOverlayButtons(QObject* parent);
    void update();
    void installOverlay(const QModelIndex& index);

    FnGetActions m_get_actions;
    QAbstractItemView* m_view;
};


#endif // BORNAGAIN_GUI_VIEW_WIDGET_ITEMVIEWOVERLAYBUTTONS_H
