#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/InstrumentsSet.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "Tests/GTestWrapper/google_test.h"
#include <QSignalSpy>

Q_DECLARE_METATYPE(const InstrumentItem*)

//! Checks whether instrumentAddedRemoved will be emitted as expected

TEST(TestInstrumentCollection, instrumentAddedRemoved)
{
    auto doc = std::make_unique<ProjectDocument>();

    QSignalSpy spy(doc->instruments(), SIGNAL(instrumentAddedOrRemoved()));
    EXPECT_TRUE(spy.isValid());

    // populating instrument model
    auto* p = doc->instrumentsModifier()->addInstrumentItem<GISASInstrumentItem>();

    // checking that a signal was emitted about the new instrument
    EXPECT_EQ(spy.count(), 1);

    // removing instrument
    doc->instrumentsModifier()->removeInstrument(p);
    EXPECT_EQ(spy.count(), 2);
}

//! Test whether instrumentChanged will be emitted as expected
TEST(TestInstrumentCollection, instrumentChanged)
{
    qRegisterMetaType<const InstrumentItem*>();
    auto doc = std::make_unique<ProjectDocument>();

    // populating instrument model
    auto* instrument1 = doc->instrumentsModifier()->addInstrumentItem<GISASInstrumentItem>();
    auto* instrument2 = doc->instrumentsModifier()->addInstrumentItem<SpecularInstrumentItem>();

    QSignalSpy spy(doc->instruments(), SIGNAL(instrumentChanged(const InstrumentItem*)));
    EXPECT_TRUE(spy.isValid());

    // change name of instrument 1
    doc->instrumentsModifier()->setInstrumentName(instrument1, "A");
    EXPECT_EQ(spy.count(), 1);
    const auto* instr = qvariant_cast<const InstrumentItem*>(spy.at(0).at(0));
    EXPECT_EQ(instr, instrument1);

    // change other properties, e.g. id
    instrument1->setId("xxxxx");
    emit doc->instruments()->instrumentChanged(instrument1);
    EXPECT_EQ(spy.count(), 2);

    // change name of instrument 2
    doc->instrumentsModifier()->setInstrumentName(instrument2, "B");
    EXPECT_EQ(spy.count(), 3);
    instr = qvariant_cast<const InstrumentItem*>(spy.at(2).at(0));
    EXPECT_EQ(instr, instrument2);

    // Add another instrument
    auto* instrument3 = doc->instrumentsModifier()->addInstrumentItem<OffspecInstrumentItem>();

    // Change instrument2
    doc->instrumentsModifier()->setInstrumentName(instrument2, "BB");
    EXPECT_EQ(spy.count(), 4);
    instr = qvariant_cast<const InstrumentItem*>(spy.at(3).at(0));
    EXPECT_EQ(instr, instrument2);

    // Change instrument3
    doc->instrumentsModifier()->setInstrumentName(instrument3, "C");
    EXPECT_EQ(spy.count(), 5);
    instr = qvariant_cast<const InstrumentItem*>(spy.at(4).at(0));
    EXPECT_EQ(instr, instrument3);
}
